==> chaosmesh-model-6.9.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkPartitionSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class NetworkPartitionSpecFluent<A extends NetworkPartitionSpecFluent<A>> extends BaseFluent<A>{
  public NetworkPartitionSpecFluent() {
  }
  
  public NetworkPartitionSpecFluent(NetworkPartitionSpec instance) {
    this.copyInstance(instance);
  }
  private String acceptTcpFlags;
  private String device;
  private String direction;
  private String hostname;
  private String ipAddress;
  private String ipProtocol;
  
  protected void copyInstance(NetworkPartitionSpec instance) {
    instance = (instance != null ? instance : new NetworkPartitionSpec());
    if (instance != null) {
          this.withAcceptTcpFlags(instance.getAcceptTcpFlags());
          this.withDevice(instance.getDevice());
          this.withDirection(instance.getDirection());
          this.withHostname(instance.getHostname());
          this.withIpAddress(instance.getIpAddress());
          this.withIpProtocol(instance.getIpProtocol());
          this.withAcceptTcpFlags(instance.getAcceptTcpFlags());
          this.withDevice(instance.getDevice());
          this.withDirection(instance.getDirection());
          this.withHostname(instance.getHostname());
          this.withIpAddress(instance.getIpAddress());
          this.withIpProtocol(instance.getIpProtocol());
        }
  }
  
  public String getAcceptTcpFlags() {
    return this.acceptTcpFlags;
  }
  
  public A withAcceptTcpFlags(String acceptTcpFlags) {
    this.acceptTcpFlags = acceptTcpFlags;
    return (A) this;
  }
  
  public boolean hasAcceptTcpFlags() {
    return this.acceptTcpFlags != null;
  }
  
  public String getDevice() {
    return this.device;
  }
  
  public A withDevice(String device) {
    this.device = device;
    return (A) this;
  }
  
  public boolean hasDevice() {
    return this.device != null;
  }
  
  public String getDirection() {
    return this.direction;
  }
  
  public A withDirection(String direction) {
    this.direction = direction;
    return (A) this;
  }
  
  public boolean hasDirection() {
    return this.direction != null;
  }
  
  public String getHostname() {
    return this.hostname;
  }
  
  public A withHostname(String hostname) {
    this.hostname = hostname;
    return (A) this;
  }
  
  public boolean hasHostname() {
    return this.hostname != null;
  }
  
  public String getIpAddress() {
    return this.ipAddress;
  }
  
  public A withIpAddress(String ipAddress) {
    this.ipAddress = ipAddress;
    return (A) this;
  }
  
  public boolean hasIpAddress() {
    return this.ipAddress != null;
  }
  
  public String getIpProtocol() {
    return this.ipProtocol;
  }
  
  public A withIpProtocol(String ipProtocol) {
    this.ipProtocol = ipProtocol;
    return (A) this;
  }
  
  public boolean hasIpProtocol() {
    return this.ipProtocol != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetworkPartitionSpecFluent that = (NetworkPartitionSpecFluent) o;
    if (!java.util.Objects.equals(acceptTcpFlags, that.acceptTcpFlags)) return false;
    if (!java.util.Objects.equals(device, that.device)) return false;
    if (!java.util.Objects.equals(direction, that.direction)) return false;
    if (!java.util.Objects.equals(hostname, that.hostname)) return false;
    if (!java.util.Objects.equals(ipAddress, that.ipAddress)) return false;
    if (!java.util.Objects.equals(ipProtocol, that.ipProtocol)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(acceptTcpFlags,  device,  direction,  hostname,  ipAddress,  ipProtocol,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (acceptTcpFlags != null) { sb.append("acceptTcpFlags:"); sb.append(acceptTcpFlags + ","); }
    if (device != null) { sb.append("device:"); sb.append(device + ","); }
    if (direction != null) { sb.append("direction:"); sb.append(direction + ","); }
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (ipAddress != null) { sb.append("ipAddress:"); sb.append(ipAddress + ","); }
    if (ipProtocol != null) { sb.append("ipProtocol:"); sb.append(ipProtocol); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> chaosmesh-model-7.4.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkPartitionSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class NetworkPartitionSpecFluent<A extends NetworkPartitionSpecFluent<A>> extends BaseFluent<A>{
  public NetworkPartitionSpecFluent() {
  }
  
  public NetworkPartitionSpecFluent(NetworkPartitionSpec instance) {
    this.copyInstance(instance);
  }
  private String acceptTcpFlags;
  private String device;
  private String direction;
  private String hostname;
  private String ipAddress;
  private String ipProtocol;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(NetworkPartitionSpec instance) {
    instance = (instance != null ? instance : new NetworkPartitionSpec());
    if (instance != null) {
          this.withAcceptTcpFlags(instance.getAcceptTcpFlags());
          this.withDevice(instance.getDevice());
          this.withDirection(instance.getDirection());
          this.withHostname(instance.getHostname());
          this.withIpAddress(instance.getIpAddress());
          this.withIpProtocol(instance.getIpProtocol());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getAcceptTcpFlags() {
    return this.acceptTcpFlags;
  }
  
  public A withAcceptTcpFlags(String acceptTcpFlags) {
    this.acceptTcpFlags = acceptTcpFlags;
    return (A) this;
  }
  
  public boolean hasAcceptTcpFlags() {
    return this.acceptTcpFlags != null;
  }
  
  public String getDevice() {
    return this.device;
  }
  
  public A withDevice(String device) {
    this.device = device;
    return (A) this;
  }
  
  public boolean hasDevice() {
    return this.device != null;
  }
  
  public String getDirection() {
    return this.direction;
  }
  
  public A withDirection(String direction) {
    this.direction = direction;
    return (A) this;
  }
  
  public boolean hasDirection() {
    return this.direction != null;
  }
  
  public String getHostname() {
    return this.hostname;
  }
  
  public A withHostname(String hostname) {
    this.hostname = hostname;
    return (A) this;
  }
  
  public boolean hasHostname() {
    return this.hostname != null;
  }
  
  public String getIpAddress() {
    return this.ipAddress;
  }
  
  public A withIpAddress(String ipAddress) {
    this.ipAddress = ipAddress;
    return (A) this;
  }
  
  public boolean hasIpAddress() {
    return this.ipAddress != null;
  }
  
  public String getIpProtocol() {
    return this.ipProtocol;
  }
  
  public A withIpProtocol(String ipProtocol) {
    this.ipProtocol = ipProtocol;
    return (A) this;
  }
  
  public boolean hasIpProtocol() {
    return this.ipProtocol != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetworkPartitionSpecFluent that = (NetworkPartitionSpecFluent) o;
    if (!java.util.Objects.equals(acceptTcpFlags, that.acceptTcpFlags)) return false;
    if (!java.util.Objects.equals(device, that.device)) return false;
    if (!java.util.Objects.equals(direction, that.direction)) return false;
    if (!java.util.Objects.equals(hostname, that.hostname)) return false;
    if (!java.util.Objects.equals(ipAddress, that.ipAddress)) return false;
    if (!java.util.Objects.equals(ipProtocol, that.ipProtocol)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(acceptTcpFlags,  device,  direction,  hostname,  ipAddress,  ipProtocol,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (acceptTcpFlags != null) { sb.append("acceptTcpFlags:"); sb.append(acceptTcpFlags + ","); }
    if (device != null) { sb.append("device:"); sb.append(device + ","); }
    if (direction != null) { sb.append("direction:"); sb.append(direction + ","); }
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (ipAddress != null) { sb.append("ipAddress:"); sb.append(ipAddress + ","); }
    if (ipProtocol != null) { sb.append("ipProtocol:"); sb.append(ipProtocol + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
